@@ -1,6 +1,6 @@
 """
 /******************************************************************************
- * $Id: core.py 1001 2009-02-06 03:03:13Z hobu $
+ * $Id: core.py 1125 2009-03-20 16:57:55Z hobu $
  *
  * Project:  libLAS - http://liblas.org - A BSD library for LAS format data.
  * Purpose:  Python ctypes function calls
@@ -69,12 +69,13 @@ def check_void(result, func, cargs):
 
 def check_void_done(result, func, cargs):
     "Error checking for void* returns that might be empty with no error"
-    if not bool(result):
-        if las.LASError_GetErrorCount():
-            msg = 'LASError in "%s": %s' % (func.__name__, las.LASError_GetLastErrorMsg() )
-            las.LASError_Reset()
-            raise LASException(msg)
+    if las.LASError_GetErrorCount():
+        msg = 'LASError in "%s": %s' % (func.__name__, las.LASError_GetLastErrorMsg() )
+        las.LASError_Reset()
+        raise LASException(msg)
+        
     return result
+
 def check_value(result, func, cargs):
     "Error checking proper value returns"
     count = las.LASError_GetErrorCount()
@@ -147,10 +148,12 @@ def get_version():
     
 version = get_version()
 
+las.LAS_IsGDALEnabled.restype = ctypes.c_int
+las.LAS_IsLibGeoTIFFEnabled.restype = ctypes.c_int
+
 las.LAS_GetVersion.restype = ctypes.POINTER(ctypes.c_char)
 las.LAS_GetVersion.errcheck = free_returned_char_p
 
-las.LAS_GetVersion.restype = ctypes.c_char_p
 las.LASError_GetLastErrorNum.restype = ctypes.c_int
 
 las.LASError_GetLastErrorMsg.restype = ctypes.POINTER(ctypes.c_char)
@@ -173,6 +176,13 @@ las.LASReader_GetPointAt.restype = ctypes.c_void_p
 las.LASReader_GetPointAt.argtypes = [ctypes.c_void_p, ctypes.c_ulong]
 las.LASReader_GetPointAt.errcheck = check_void_done
 
+las.LASReader_SetSRS.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
+las.LASReader_SetSRS.errcheck = check_return
+
+las.LASReader_Destroy.argtypes = [ctypes.c_void_p]
+las.LASReader_Destroy.errcheck = check_void_done
+las.LASReader_Destroy.restype = None
+
 las.LASPoint_GetX.restype = ctypes.c_double
 las.LASPoint_GetX.argtypes = [ctypes.c_void_p]
 las.LASPoint_GetX.errcheck = check_value
@@ -276,6 +286,8 @@ las.LASReader_GetHeader.argtypes = [ctypes.c_void_p]
 las.LASReader_GetHeader.errcheck = check_void
 
 las.LASHeader_Destroy.argtypes = [ctypes.c_void_p]
+las.LASHeader_Destroy.errcheck = check_void_done
+las.LASHeader_Destroy.restype = None
 
 las.LASHeader_Copy.restype = ctypes.c_void_p
 las.LASHeader_Copy.argtypes = [ctypes.c_void_p]
@@ -428,12 +440,6 @@ las.LASHeader_SetMax.restype = ctypes.c_int
 las.LASHeader_SetMax.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_double, ctypes.c_double]
 las.LASHeader_SetMax.errcheck = check_return
 
-las.LASHeader_GetProj4.argtypes = [ctypes.c_void_p]
-las.LASHeader_GetProj4.errcheck = check_value_free
-las.LASHeader_SetProj4.restype = ctypes.c_int
-las.LASHeader_SetProj4.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
-las.LASHeader_SetProj4.errcheck = check_return
-
 las.LASHeader_GetVLR.argtypes = [ctypes.c_void_p, ctypes.c_int]
 las.LASHeader_GetVLR.errcheck = check_void
 las.LASHeader_GetVLR.restype = ctypes.c_void_p
@@ -456,11 +462,16 @@ las.LASWriter_WriteHeader.restype = ctypes.c_int
 las.LASWriter_WriteHeader.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
 las.LASWriter_WriteHeader.errcheck = check_return
 
+las.LASWriter_SetSRS.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
+las.LASWriter_SetSRS.errcheck = check_return
+
 las.LASWriter_Destroy.argtypes = [ctypes.c_void_p]
 las.LASWriter_Destroy.errcheck = check_void_done
+las.LASWriter_Destroy.restype = None
 
 las.LASGuid_Destroy.argtypes = [ctypes.c_void_p]
 las.LASGuid_Destroy.errcheck = check_void_done
+las.LASGuid_Destroy.restype = None
 
 las.LASGuid_AsString.argtypes = [ctypes.c_void_p]
 las.LASGuid_AsString.errcheck = check_value_free
@@ -488,6 +499,7 @@ las.LASVLR_Create.restype = ctypes.c_void_p
 
 las.LASVLR_Destroy.argtypes = [ctypes.c_void_p]
 las.LASVLR_Destroy.errcheck = check_void_done
+las.LASVLR_Destroy.restype = None
 
 las.LASVLR_GetUserId.argtypes = [ctypes.c_void_p]
 las.LASVLR_GetUserId.errcheck = check_value_free
@@ -530,3 +542,75 @@ las.LASVLR_SetData.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_ubyte)]
 las.LASVLR_SetData.errcheck = check_value
 las.LASVLR_SetData.restype = ctypes.c_int
 
+
+las.LASColor_Create.errcheck = check_void
+las.LASColor_Create.restype = ctypes.c_void_p
+
+las.LASColor_Destroy.argtypes = [ctypes.c_void_p]
+las.LASColor_Destroy.errcheck = check_void_done
+las.LASColor_Destroy.restype = None
+
+las.LASColor_GetRed.restype = ctypes.c_short
+las.LASColor_GetRed.argtypes = [ctypes.c_void_p]
+las.LASColor_GetRed.errcheck = check_value
+las.LASColor_SetRed.restype = ctypes.c_int
+las.LASColor_SetRed.argtypes = [ctypes.c_void_p, ctypes.c_short]
+las.LASColor_SetRed.errcheck = check_return
+
+las.LASColor_GetGreen.restype = ctypes.c_short
+las.LASColor_GetGreen.argtypes = [ctypes.c_void_p]
+las.LASColor_GetGreen.errcheck = check_value
+las.LASColor_SetGreen.restype = ctypes.c_int
+las.LASColor_SetGreen.argtypes = [ctypes.c_void_p, ctypes.c_short]
+las.LASColor_SetGreen.errcheck = check_return
+
+las.LASColor_GetBlue.restype = ctypes.c_short
+las.LASColor_GetBlue.argtypes = [ctypes.c_void_p]
+las.LASColor_GetBlue.errcheck = check_value
+las.LASColor_SetBlue.restype = ctypes.c_int
+las.LASColor_SetBlue.argtypes = [ctypes.c_void_p, ctypes.c_short]
+las.LASColor_SetBlue.errcheck = check_return
+
+las.LASPoint_GetColor.argtypes = [ctypes.c_void_p]
+las.LASPoint_GetColor.errcheck = check_void
+las.LASPoint_GetColor.restype = ctypes.c_void_p
+
+las.LASPoint_SetColor.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
+las.LASPoint_SetColor.errcheck = check_return
+
+las.LASSRS_Create.errcheck = check_void
+las.LASSRS_Create.restype = ctypes.c_void_p
+
+las.LASSRS_Destroy.argtypes = [ctypes.c_void_p]
+las.LASSRS_Destroy.errcheck = check_void_done
+las.LASSRS_Destroy.restype = None
+
+las.LASSRS_GetProj4.argtypes = [ctypes.c_void_p]
+las.LASSRS_GetProj4.errcheck = check_value_free
+las.LASSRS_SetProj4.restype = ctypes.c_int
+las.LASSRS_SetProj4.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
+las.LASSRS_SetProj4.errcheck = check_return
+
+las.LASSRS_GetWKT.argtypes = [ctypes.c_void_p]
+las.LASSRS_GetWKT.errcheck = check_value_free
+las.LASSRS_SetWKT.restype = ctypes.c_int
+las.LASSRS_SetWKT.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
+las.LASSRS_SetWKT.errcheck = check_return
+
+las.LASSRS_AddVLR.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
+las.LASSRS_AddVLR.errcheck = check_value
+las.LASSRS_AddVLR.restype = ctypes.c_int
+
+las.LASSRS_GetVLR.argtypes = [ctypes.c_void_p, ctypes.c_int]
+las.LASSRS_GetVLR.errcheck = check_void
+las.LASSRS_GetVLR.restype = ctypes.c_void_p
+
+las.LASSRS_GetVLRCount.argtypes = [ctypes.c_void_p]
+las.LASSRS_GetVLRCount.restype = ctypes.c_int
+
+las.LASHeader_GetSRS.argtypes = [ctypes.c_void_p]
+las.LASHeader_GetSRS.errcheck = check_void
+las.LASHeader_GetSRS.restype = ctypes.c_void_p
+
+las.LASHeader_SetSRS.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
+las.LASHeader_SetSRS.errcheck = check_return
